@@ -6,17 +6,19 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_CONTACTQUERY_H
-#define AKONADI_SEARCH_PIM_CONTACTQUERY_H
+#pragma once
 
-#include "search_pim_export.h"
 #include "query.h"
+#include "search_pim_export.h"
 
 #include <QString>
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 /**
  * Query for a list of contacts matching a criteria
  */
@@ -24,7 +26,7 @@ class AKONADI_SEARCH_PIM_EXPORT ContactQuery : public Query
 {
 public:
     ContactQuery();
-    ~ContactQuery();
+    ~ContactQuery() override;
 
     void matchName(const QString &name);
     void matchNickname(const QString &nick);
@@ -32,10 +34,7 @@ public:
     void matchUID(const QString &uid);
     void match(const QString &str);
 
-    enum MatchCriteria {
-        ExactMatch,
-        StartsWithMatch
-    };
+    enum MatchCriteria { ExactMatch, StartsWithMatch };
 
     void setMatchCriteria(MatchCriteria m);
     MatchCriteria matchCriteria() const;
@@ -53,4 +52,3 @@ private:
 }
 }
 
-#endif // AKONADI_SEARCH_PIM_CONTACTQUERY_H
